# frozen_string_literal: true

SERVICE_NAME = 'feature-config'
SERVICE_TASK = 'webserver'

require 'bundler/setup'
require_relative 'system/import'

require 'feature_config/graphql'

require 'sinatra/json'
require 'sinatra/custom_logger'
require 'rollbar/middleware/sinatra'
require 'cht-lib-fabric/helpers/context'
require 'cht-lib-fabric/helpers/graphql_query'
require 'cht-lib-fabric/helpers/tokens'
require 'cht-lib-fabric/helpers/web_server'
require 'cht-lib-fabric/middleware/statsd'
require 'cht-lib-fabric/helpers/puma_stats'

Application.finalize!

##
# Main entry point to service.
# This is where you will define your routes and endpoints.
class WebServer < ::Sinatra::Base
  include Import['graphql.tracers']

  register ::Platform::Helpers::GraphQLQuery
  helpers ::Platform::Helpers::WebServer
  helpers Sinatra::CustomLogger
  register ::Platform::Helpers::Context
  register ::Platform::Helpers::Tokens
  register ::Platform::Helpers::PumaStats

  configure do
    disable :method_override
    disable :static

    set :logger, Application['logger']
    set :protection, except: :session_hijacking
    set :root, File.dirname(__FILE__)
    set :wavefront, Application[:wavefront]

    set :cht_pod, Application[:settings].pod_name
    set :jwks_uri, Application[:settings].jwks_uri
    if Application[:settings].developer_jwt_signing != '' ||
       (Application.env != :production &&
        Application[:settings].jwks_uri == '')
      enable :jwt_developer_key
    end
  end

  use ::Rollbar::Middleware::Sinatra
  use ::Rack::Deflater
  use ::Platform::Middleware::StatsD, Application['statsd']

  get '/' do
    "#{SERVICE_NAME} - #{SERVICE_TASK}"
  end

  graphql '/graphql', ::FeatureConfig::Schema
end
